__title__ = 'imagesoup'
__description__ = 'A Python library designed for quick search and downloading images.'
__url__ = 'https://github.com/rafpyprog/ImageSoup'
__version__ = '0.0.8'
__author__ = 'Rafael Alves Ribeiro'
__author_email__ = 'rafael.alves.ribeiro@gmail.com'
__license__ = 'MIT'
__copyright__ = 'Copyright 2017 Rafael Alves Ribeiro'
